export type KeyOfType<Type, ValueType> = keyof {
    [Key in keyof Type as Type[Key] extends ValueType ? Key : never]: any;
};
/**
 * Network constants.
 */
export declare class Constants {
    constructor();
    /**
     * Network id
     */
    hrp: string;
    /**
     * The RPC address of the node for network connection
     */
    rpc: string;
    /**
     * Time in milliseconds after transaction submission before
     * error is thrown if the transaction is not confirmed
     */
    txConfirmationTimeout: number;
    /**
     * Time in milliseconds that determines the delay between two
     * consecutive checks if a transaction is confirmed
     */
    txConfirmationCheckout: number;
    /**
     * The gas limit used in EVM transfers
     */
    evmTransferGasLimit: bigint;
    /**
     * The default base fee in weis used as fallback for C-chain transactions
     */
    evmBaseFee: bigint;
    /**
     * The default max fee per gas in weis used as fallback for C-chain transactions
     */
    evmMaxFeePerGas: bigint;
    /**
     * The default max priority fee per gas in weis used as fallback for C-chain transactions
     */
    evmMaxPriorityFeePerGas: bigint;
    /**
     * The address of the FlareContractRegistry contract
     */
    address_FlareContractRegistry: string;
    copy(): Constants;
    toJson(): string;
    static fromJson(json: string): Constants;
    /**
     * Default constants for the main Flare network.
     */
    static readonly FLARE: Constants;
    /**
     * Prepares default constants for the main Flare network.
     * @returns Constants of class {@link Constants}.
     */
    protected static _flare(): Constants;
    /**
     * Default constants for the canary Flare network.
     */
    static readonly SONGBIRD: Constants;
    /**
     * Prepares default constants for the canary Flare network.
     * @returns Constants of class {@link Constants}.
     */
    protected static _songbird(): Constants;
    /**
     * Default constants for the canary Flare network.
     */
    static readonly COSTON2: Constants;
    /**
     * Prepares default constants for the test Flare network.
     * @returns Constants of class {@link Constants}.
     */
    protected static _coston2(): Constants;
    /**
     * Default constants for the test canary Flare network.
     */
    static readonly COSTON: Constants;
    /**
     * Prepares default constants for the test canary Flare network.
     * @returns Constants of class {@link Constants}.
     */
    protected static _coston(): Constants;
    protected _setCommon(): void;
}
//# sourceMappingURL=constants.d.ts.map